<?php

namespace Drupal\Tests\editorial_access_manager\Functional;

/**
 * Test that proper permissions grants access to editorial manager access page.
 */
class ReassignContentTest extends EditorialAccessManagerTestsBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $entity = $this->drupalGetEntityTestByLabel('Test entity with translation assignment access');

    \Drupal::service('editorial_access_manager.manager')
      ->setEntityAssignees($entity, 'fr', [$this->assignableTranslator->id()]);
  }

  /**
   * Test that reassigning the content works.
   */
  public function testReassign() {
    $this->drupalLogin($this->translatorManager);
    $this->drupalGet('/admin/content/reassign');

    $this->getSession()->getPage()
      ->fillField('Old assignee', sprintf('%s (%s)', $this->assignableTranslator->getDisplayName(), $this->assignableTranslator->id()));
    $this->getSession()->getPage()
      ->fillField('New assignee', sprintf('%s (%s)', $this->assignableEntityTestMul->getDisplayName(), $this->assignableEntityTestMul->id()));

    $this->getSession()->getPage()->pressButton('Reassign');

    $this->assertSession()->pageTextContains('Are you sure you want to do reassign content from assignable_translator to assignable_entity_test_mul_with_bundle?');
    $this->assertSession()->pageTextContains('Resume of entities that will be assigned to assignable_entity_test_mul_with_bundle:');

    $this->assertSession()->pageTextContains('Test entity multilingual with bundle - data table');
    $this->assertSession()->pageTextContains('1');

    $this->getSession()->getPage()->pressButton('Confirm');

    $this->assertSession()->pageTextContains('All content has been reassigned from assignable_translator to assignable_entity_test_mul_with_bundle');

    $this->drupalLogin($this->assignableTranslator);

    $this->drupalGet('/admin/content/assigned');
    $this->assertSession()->pageTextContains('There is no assigned content yet.');
    $this->assertSession()->pageTextNotContains('Test entity with translation assignment access');

    $this->drupalLogin($this->assignableEntityTestMul);

    $this->drupalGet('/admin/content/assigned');
    $this->assertSession()->pageTextContains('Test entity with translation assignment access');
  }

}
